@@ -3,6 +3,7 @@
 # @Author : mocobk
 # @Email : mailmzb@qq.com
 # @Time : 2021/2/21 18:15
+import os
 import time
 from pathlib import Path
 
@@ -73,6 +74,8 @@ def create(ctx, name):
         target_file_path = Path(name) if name else Path('./').joinpath(
             f'{utils.secure_filename(iteration_name)}({CONFIG_DATA.get("tester")}).xlsm'
         )
+        if target_file_path.exists():
+            target_file_path = str(target_file_path).rsplit('.')[0] + str(int(time.time())) + '.xlsm'
         iteration_id = iterations[iteration_name]
         tapd.set_iteration_id(iteration_id)
 
